@@ -154,6 +154,16 @@ class Index(object):
         Returns:
             str: The JSON-encoded configuration.
         """
+
+        if not isinstance(self.config_.get('mask_surrounding'), dict):
+            self.config_.update({
+                'mask_surrounding': {
+                    'url': 'no_url',
+                    'params': {},
+                    'opacity': None
+                }
+            })
+
         return {
             'test_instance_notice': self.config_.get('test_instance_notice', None),
             'application_url': self.request_.route_url(
@@ -166,9 +176,11 @@ class Index(object):
             'view': self.config_.get('view', {}),
             'base_layer': self.config_.get('base_layer', {}),
             'availability': self.config_.get('availability', {}),
+            'mask_surrounding': self.config_.get('mask_surrounding'),
             'search': self.config_.get('search', {}),
             'support': self.config_.get('support', {}),
             'external_viewer': self.config_.get('external_viewer', {}),
+            'user_guide': self.config_.get('user_guide'),
             'use_tile_wms': self.config_.get('use_tile_wms', False),
             'extract_json_timeout': self.config_.get('extract_json_timeout', 60),
             'extract_pdf_timeout': self.config_.get('extract_pdf_timeout', 120)
